@@ -2,10 +2,10 @@ package Test::Sort::Sub;
 
 ## no critic: Modules::ProhibitAutomaticExportation
 
-our $DATE = '2018-01-15'; # DATE
-our $VERSION = '0.110'; # VERSION
+our $DATE = '2019-10-26'; # DATE
+our $VERSION = '0.111'; # VERSION
 
-use 5.010;
+use 5.010001;
 use strict 'subs', 'vars';
 use warnings;
 
@@ -23,25 +23,25 @@ sub sort_sub_ok {
         my $res;
 
         if ($args{output}) {
-            Sort::Sub->import("$subname");
+            Sort::Sub->import("$subname", ($args{args} ? $args{args} : ()));
             $res = [sort {&{$subname}} @{ $args{input} }];
             is_deeply($res, $args{output}, 'result') or diag explain $res;
         }
 
         if ($args{output_i}) {
-            Sort::Sub->import("$subname<i>");
+            Sort::Sub->import("$subname<i>", ($args{args} ? $args{args} : ()));
             $res = [sort {&{$subname}} @{ $args{input} }];
             is_deeply($res, $args{output_i}, 'result i') or diag explain $res;
         }
 
         if ($args{output_r}) {
-            Sort::Sub->import("$subname<r>");
+            Sort::Sub->import("$subname<r>", ($args{args} ? $args{args} : ()));
             $res = [sort {&{$subname}} @{ $args{input} }];
             is_deeply($res, $args{output_r}, 'result r') or diag explain $res;
         };
 
         if ($args{output_ir}) {
-            Sort::Sub->import("$subname<ir>");
+            Sort::Sub->import("$subname<ir>", ($args{args} ? $args{args} : ()));
             $res = [sort {&{$subname}} @{ $args{input} }];
             is_deeply($res, $args{output_ir}, 'result ir') or diag explain $res;
         };
@@ -63,7 +63,7 @@ Test::Sort::Sub - Test Sort::Sub::* subroutine
 
 =head1 VERSION
 
-This document describes version 0.110 of Test::Sort::Sub (from Perl distribution Sort-Sub), released on 2018-01-15.
+This document describes version 0.111 of Test::Sort::Sub (from Perl distribution Sort-Sub), released on 2019-10-26.
 
 =head1 FUNCTIONS
 
@@ -91,7 +91,7 @@ perlancar <perlancar@cpan.org>
 
 =head1 COPYRIGHT AND LICENSE
 
-This software is copyright (c) 2018, 2016, 2015 by perlancar@cpan.org.
+This software is copyright (c) 2019, 2018, 2016, 2015 by perlancar@cpan.org.
 
 This is free software; you can redistribute it and/or modify it under
 the same terms as the Perl 5 programming language system itself.
